@@ -62,13 +62,8 @@ KonqViewManager::KonqViewManager( KonqMainWindow *mainWindow )
   m_pamProfiles = 0L;
   m_bProfileListDirty = true;
   m_bLoadingProfile = false;
-
-  m_activePartChangedTimer = new QTimer(this);
-  m_activePartChangedTimer->setSingleShot(true);
-
   m_tabContainer = 0;
 
-  connect(m_activePartChangedTimer, SIGNAL(timeout()), this, SLOT( emitActivePartChanged()));
   connect( this, SIGNAL( activePartChanged ( KParts::Part * ) ),
            this, SLOT( slotActivePartChanged ( KParts::Part * ) ) );
 }
@@ -301,8 +296,8 @@ void KonqViewManager::breakOffTab( KonqFrameBase* currentFrame, const QSize& win
 
   KTemporaryFile tempFile;
   tempFile.open();
-  KConfig config( tempFile.fileName() );
-  KConfigGroup profileGroup( &config, "Profile" );
+  KSharedConfigPtr config = KSharedConfig::openConfig( tempFile.fileName() );
+  KConfigGroup profileGroup( config, "Profile" );
 
   QString prefix = QString::fromLatin1( currentFrame->frameType() ) + QString::number(0);
   profileGroup.writeEntry( "RootItem", prefix );
@@ -312,7 +307,7 @@ void KonqViewManager::breakOffTab( KonqFrameBase* currentFrame, const QSize& win
 
   KonqMainWindow *mainWindow = new KonqMainWindow(KUrl(), m_pMainWindow->xmlFile());
 
-  mainWindow->viewManager()->loadViewProfileFromGroup( profileGroup, QString() );
+  mainWindow->viewManager()->loadViewProfileFromConfig( config, QString(), currentProfile() );
 
   KonqFrameTabs * kft = mainWindow->viewManager()->tabContainer();
   KonqFrameBase *newFrame = dynamic_cast<KonqFrameBase*>(kft->currentWidget());
@@ -357,7 +352,7 @@ KonqMainWindow *KonqViewManager::openSavedWindow(const KConfigGroup& configGroup
         // Window size comes from the applyMainWindowSettings call below
     }
 
-    mainWindow->viewManager()->loadRootItem( configGroup, mainWindow->viewManager()->tabContainer(), KUrl(), true, KUrl() );
+    mainWindow->viewManager()->loadRootItem( configGroup, mainWindow, KUrl(), true, KUrl() );
     mainWindow->applyMainWindowSettings( configGroup, true );
     mainWindow->activateChild();
     kDebug(1202) << "done";
@@ -417,9 +412,14 @@ void KonqViewManager::reloadAllTabs( )
 
 void KonqViewManager::removeOtherTabs( KonqFrameBase* currentFrame )
 {
+  Q_ASSERT(currentFrame);
+
+  // currentFrame might be a frame contained inside a splitted frame so what we'll
+  // do here is just compare if the frames are inside the same tab.
+  currentFrame = m_tabContainer->tabContaining(currentFrame);
   foreach ( KonqFrameBase* frame, m_tabContainer->childFrameList() )
   {
-    if ( frame && frame != currentFrame )
+    if ( frame && m_tabContainer->tabContaining(frame) != currentFrame )
       removeTab(frame);
   }
 
@@ -961,8 +961,6 @@ void KonqViewManager::setActivePart( KParts::Part *part, bool immediate )
     //if ( part )
     //    kDebug(1202) << part->metaObject()->className() << part->name();
 
-    // Due to the single-shot timer below, we need to also make sure that
-    // the mainwindow also has the right part active already
     KParts::Part* mainWindowActivePart = m_pMainWindow->currentView()
                                          ? m_pMainWindow->currentView()->part() : 0;
     if (part == activePart() && (!immediate || mainWindowActivePart == part))
@@ -993,20 +991,7 @@ void KonqViewManager::setActivePart( KParts::Part *part, bool immediate )
     if (part && part->widget())
         part->widget()->setFocus();
 
-    if (!immediate && reason() != ReasonRightClick) {
-        // We use a 0s single shot timer so that when left-clicking on a part,
-        // we process the mouse event before rebuilding the GUI.
-        // Otherwise, when e.g. dragging icons, the mouse pointer can already
-        // be very far from where it was...
-        // TODO: use a QTimer member var, so that if two conflicting calls to
-        // setActivePart(part,immediate=false) happen, the 1st one gets canceled.
-        m_activePartChangedTimer->start( 0 );
-        // This is not done with right-clicking so that the part is activated before the
-        // popup appears (#75201)
-    } else {
-        m_activePartChangedTimer->stop();
-        emitActivePartChanged();
-    }
+    emitActivePartChanged();
 }
 
 void KonqViewManager::slotActivePartChanged ( KParts::Part *newPart )
